@@ -3,18 +3,335 @@ from __future__ import unicode_literals
 from tkinter import filedialog, ttk
 from tkinter.messagebox import showerror
 from tkinter import *
+from pickle import dumps
 
 import os
 
 
-class SG(Tk):
+class KSG(Tk):
     __pointer = None
 
-    def __init__(self, local_db_dir, main_db_path=None, pepper_key_path=None, salt_key_path=None, pointer=None):
+    def __init__(self, local_dir):
+        Tk.__init__(self)
+
+        self.__local_dir = local_dir
+        self.__key_generated = False
+        self.__salt_key_path = StringVar()
+        self.__pepper_key_path = StringVar()
+        self.__salt_key_dir = StringVar()
+        self.__pepper_key_dir = StringVar()
+
+        self.__build()
+
+    @property
+    def key_generated(self):
+        return self.__key_generated
+
+    def __build(self):
+        header = ['Welcome to Salt & Pepper setup!', 'Please fill out the below fields to setup']
+        header2 = ['Welcome to existing Salt & Pepper setup!', 'Please fill out the below fields to setup']
+
+        # Set GUI Geometry and GUI Title
+        self.geometry('280x215+550+150')
+        self.title('Salt & Pepper Setup')
+        self.resizable(False, False)
+
+        # Set GUI Frames
+        t = ttk.Notebook(self)
+        new_tab = ttk.Frame(t)
+        existing_tab = ttk.Frame(t)
+        t.add(new_tab, text='New Setup')
+        t.add(existing_tab, text='Existing')
+
+        new_header_frame = Frame(new_tab)
+        new_salt_frame = LabelFrame(new_tab, text='Salt Key', width=508, height=70)
+        new_pepper_frame = LabelFrame(new_tab, text='Pepper Key', width=508, height=70)
+        new_buttons_frame = Frame(new_tab)
+        existing_header_frame = Frame(existing_tab)
+        existing_salt_frame = LabelFrame(existing_tab, text='Salt Key', width=508, height=70)
+        existing_pepper_frame = LabelFrame(existing_tab, text='Pepper Key', width=508, height=70)
+        existing_buttons_frame = Frame(existing_tab)
+
+        # Apply Frames into GUI
+        t.pack(fill="both")
+        new_header_frame.pack(fill="both")
+        new_salt_frame.pack(fill="both")
+        new_pepper_frame.pack(fill="both")
+        new_buttons_frame.pack(fill="both")
+        existing_header_frame.pack(fill="both")
+        existing_salt_frame.pack(fill="both")
+        existing_pepper_frame.pack(fill="both")
+        existing_buttons_frame.pack(fill="both")
+
+        # Apply Header text to Header_Frame that describes purpose of GUI
+        header = Message(self, text='\n'.join(header), width=500, justify=CENTER)
+        header.pack(in_=new_header_frame)
+        header2 = Message(self, text='\n'.join(header2), width=500, justify=CENTER)
+        header2.pack(in_=existing_header_frame)
+
+        # Apply Widgets to new_salt_frame
+        #   Apply Salt Directory Entry Box Widget
+        salt_dir_label = Label(new_salt_frame, text='Salt Dir:')
+        salt_dir_entry = Entry(new_salt_frame, textvariable=self.__salt_key_dir)
+        salt_dir_label.grid(row=0, column=0, padx=4, pady=5)
+        salt_dir_entry.grid(row=0, column=1, padx=4, pady=5)
+
+        #   Apply Salt Directory Finder Button Widget
+        find_salt_dir_button = Button(new_salt_frame, text='...', width=8, command=self.__salt_dir_gui)
+        find_salt_dir_button.grid(row=0, column=2, padx=4, pady=5)
+
+        # Apply Widgets to new_settings_frame
+        #    Apply Pepper Directory Entry Box Widget
+        pepper_dir_label = Label(new_pepper_frame, text='Pepper Dir:')
+        pepper_dir_entry = Entry(new_pepper_frame, textvariable=self.__pepper_key_dir)
+        pepper_dir_label.grid(row=0, column=0, padx=4, pady=5)
+        pepper_dir_entry.grid(row=0, column=1, padx=4, pady=5)
+
+        #   Apply Pepper Directory Finder Button Widget
+        find_pepper_dir_button = Button(new_pepper_frame, text='...', width=8, command=self.__pepper_dir_gui)
+        find_pepper_dir_button.grid(row=0, column=2, padx=4, pady=5)
+
+        # Apply Buttons to the new_buttons_frame
+        #     Generate button
+        generate_button = Button(self, text='Generate', width=15, command=self.__generate)
+        generate_button.pack(in_=new_buttons_frame, side=LEFT, padx=7, pady=7)
+
+        #     Cancel button
+        cancel_button = Button(self, text='Cancel', width=15, command=self.destroy)
+        cancel_button.pack(in_=new_buttons_frame, side=RIGHT, padx=7, pady=7)
+
+        # Apply Widgets to existing_frame
+        #   Apply Salt Directory Entry Box Widget
+        salt_fp_label = Label(existing_salt_frame, text='Salt FP:')
+        salt_fp_entry = Entry(existing_salt_frame, textvariable=self.__salt_key_path)
+        salt_fp_label.grid(row=0, column=0, padx=4, pady=5)
+        salt_fp_entry.grid(row=0, column=1, padx=4, pady=5)
+
+        #   Apply Salt File Name Finder Button Widget
+        find_salt_name_button = Button(existing_salt_frame, text='...', width=8, command=self.__salt_file_gui)
+        find_salt_name_button.grid(row=0, column=2, padx=4, pady=5)
+
+        #   Apply Main Filepath Entry Box Widget
+        pepper_fp_label = Label(existing_pepper_frame, text='Pepper FP:')
+        pepper_fp_entry = Entry(existing_pepper_frame, textvariable=self.__pepper_path)
+        pepper_fp_label.grid(row=1, column=0, padx=4, pady=5)
+        pepper_fp_entry.grid(row=1, column=1, padx=4, pady=5)
+
+        #   Apply Main Filepath Finder Button Widget
+        find_pepper_fp_button = Button(existing_pepper_frame, text='...', width=3, command=self.__pepper_fp_gui)
+        find_pepper_fp_button.grid(row=1, column=2, padx=4, pady=5)
+
+        # Apply Buttons to the existing_buttons_frame
+        #     Generate button
+        generate_button = Button(self, text='Generate', width=15, command=self.__generate2)
+        generate_button.pack(in_=existing_buttons_frame, side=LEFT, padx=7, pady=7)
+
+        #     Cancel button
+        cancel_button = Button(self, text='Cancel', width=15, command=self.destroy)
+        cancel_button.pack(in_=existing_buttons_frame, side=RIGHT, padx=7, pady=7)
+
+    def __salt_dir_gui(self):
+        if self.__salt_key_dir.get() and os.path.exists(self.__salt_key_dir.get()):
+            init_dir = self.__salt_key_dir.get()
+        else:
+            init_dir = self.__local_dir
+
+        salt_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Salt Key Directory', parent=self)
+
+        if salt_dir:
+            self.__salt_key_dir.set(salt_dir)
+
+    def __salt_file_gui(self):
+        if self.__salt_key_path.get() and os.path.exists(self.__salt_key_path.get()):
+            init_dir = os.path.dirname(self.__salt_key_path.get())
+            init_file = os.path.basename(self.__salt_key_path.get())
+        else:
+            init_dir = self.__local_dir
+            init_file = ''
+
+        file_path = filedialog.askopenfile(initialdir=init_dir, initialfile=init_file, title='Select Salt Key',
+                                           filetypes=[("key files", "*.key")], parent=self)
+
+        if file_path:
+            self.__salt_key_path.set(file_path.name)
+            file_path.close()
+
+    def __pepper_dir_gui(self):
+        if self.__pepper_key_dir.get() and os.path.exists(self.__pepper_key_dir.get()):
+            init_dir = self.__pepper_key_dir.get()
+        else:
+            init_dir = self.__local_dir
+
+        settings_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Pepper Key Directory',
+                                               parent=self)
+
+        if settings_dir:
+            self.__pepper_key_dir.set(settings_dir)
+
+    def __pepper_file_gui(self):
+        if self.__pepper_key_path.get() and os.path.exists(self.__pepper_key_path.get()):
+            init_dir = os.path.dirname(self.__pepper_key_path.get())
+            init_file = os.path.basename(self.__pepper_key_path.get())
+        else:
+            init_dir = self.__local_dir
+            init_file = ''
+
+        settings_name = filedialog.askopenfile(initialdir=init_dir, initialfile=init_file,
+                                               title='Select Pepper Key', filetypes=[("key files", "*.key")],
+                                               parent=self)
+
+        if settings_name:
+            self.__pepper_key_path.set(settings_name.name)
+            settings_name.close()
+
+    def __generate2(self):
+        from . import default_key_dir
+        key_dir = default_key_dir()
+
+        if not self.__salt_key_path:
+            showerror('Field Empty Error!', 'No value has been inputed for Salt Key Path', parent=self)
+        elif not self.__pepper_key_path:
+            showerror('Field Empty Error!', 'No value has been inputed for Pepper Key Path', parent=self)
+        elif not os.path.isfile(self.__salt_key_path.get()):
+            showerror('Invalid Path Error!', 'Salt Key Path is not a file!', parent=self)
+        elif not os.path.isfile(self.__pepper_key_path.get()):
+            showerror('Invalid Path Error!', 'Pepper Key Path is not a file!', parent=self)
+        elif not os.path.exists(self.__salt_key_path.get()):
+            showerror('Path Exist Error!', 'Salt Key Path does not exist!', parent=self)
+        elif not os.path.exists(self.__pepper_key_path.get()):
+            showerror('Path Exist Error!', 'Pepper Key Path does not exist!', parent=self)
+        elif os.path.dirname(self.salt_key_path.get()).lower() == key_dir.lower():
+            showerror('Default Path Error!', 'No need to point to default path for Salt Key!', parent=self)
+        elif os.path.dirname(self.pepper_key_path.get()).lower() == key_dir.lower():
+            showerror('Default Path Error!', 'No need to point to default path for Pepper Key!', parent=self)
+        else:
+            from .data import file_write_bytes, KeyPtr
+
+            key_ptr_fp = os.path.join(key_dir, "Key.dir")
+            key_ptr = KeyPtr(salt_key_fp=self.salt_key_path.get(), pepper_key_fp=self.pepper_key_path.get())
+            file_write_bytes(key_ptr_fp, dumps(key_ptr))
+            self.__key_generated = True
+
+            self.destroy()
+
+    def __generate(self):
+        if not self.__salt_key_dir:
+            showerror('Field Empty Error!', 'No value has been inputed for Salt Key Directory', parent=self)
+        elif not self.__pepper_key_dir:
+            showerror('Field Empty Error!', 'No value has been inputed for Pepper Key Directory', parent=self)
+        elif not os.path.isdir(self.__salt_key_dir.get()):
+            showerror('Invalid Directory!', 'Salt Key Directory is an invalid directory', parent=self)
+        elif not os.path.isdir(self.__pepper_key_dir.get()):
+            showerror('Invalid Directory!', 'Pepper Key Directory is an invalid directory', parent=self)
+        elif not os.path.exists(self.__salt_key_dir.get()):
+            showerror('Directory Not Exist!', 'Salt Key Directory does not exist', parent=self)
+        elif not os.path.exists(self.__pepper_key_dir.get()):
+            showerror('Directory Not Exist!', 'Pepper Key Directory does not exist', parent=self)
+        else:
+            from .data import create_key
+            from . import default_key_dir
+
+            key_dir = default_key_dir()
+            key_ptr_fp = os.path.join(key_dir, "Key.dir")
+            salt_key_fp = os.path.join(self.__salt_key_dir.get(), "Salt.key")
+            pepper_key_fp = os.path.join(self.__pepper_key_dir.get(), "Pepper.key")
+            create_key(self.__salt_key_dir.get(), "Salt.key")
+            create_key(self.__pepper_key_dir.get(), "Pepper.key")
+            key_ptr = KeyPtr(salt_key_fp=salt_key_fp, pepper_key_fp=pepper_key_fp)
+            file_write_bytes(key_ptr_fp, dumps(key_ptr))
+            self.__key_generated = True
+
+            self.destroy()
+
+
+class KeySetupGUI(KSG):
+    """
+    Setup GUI for Salt Key, Main DB, Local DB, and Pointer files
+    """
+
+    def __init__(self, local_dir=None):
+        KSG.__init__(self, local_dir=local_dir)
+        self.mainloop()
+
+
+class KSG(Tk):
+    __pointer = None
+
+    def __init__(self, local_dir):
+        Tk.__init__(self)
+
+        self.__local_dir = local_dir
+        self.__key_generated = False
+        self.__specific_obj = None
+
+        self.__build()
+
+    @property
+    def key_generated(self):
+        return self.__key_generated
+
+    def __build(self):
+        header = ['Welcome to Salt & Pepper setup!', 'Would you like to install in default location?']
+
+        # Set GUI Geometry and GUI Title
+        self.geometry('280x135+550+150')
+        self.title('Salt & Pepper Setup')
+        self.resizable(False, False)
+
+        new_header_frame = Frame(new_tab)
+        new_buttons_frame = Frame(new_tab)
+
+        # Apply Frames into GUI
+        t.pack(fill="both")
+        new_header_frame.pack(fill="both")
+        new_buttons_frame.pack(fill="both")
+
+        # Apply Header text to Header_Frame that describes purpose of GUI
+        header = Message(self, text='\n'.join(header), width=500, justify=CENTER)
+        header.pack(in_=new_header_frame)
+
+        # Apply Buttons to the new_buttons_frame
+        #     Default button
+        default_button = Button(self, text='Default Location', width=15, command=self.__default)
+        default_button.pack(in_=new_buttons_frame, side=LEFT, padx=7, pady=7)
+
+        #     Cancel button
+        specific_button = Button(self, text='Specific Location', width=15, command=self.__specific)
+        specific_button.pack(in_=new_buttons_frame, side=RIGHT, padx=7, pady=7)
+
+    def __default(self):
+        if not self.__specific_obj:
+            from . import default_key_dir
+            key_dir = default_key_dir()
+
+            create_key(key_dir, "Salt.key")
+            create_key(key_dir, "Pepper.key")
+            self.__key_generated = True
+            self.destroy()
+
+    def __specific(self):
+        self.__specific_obj = KeySetupGUI(self.__local_dir)
+        self.__key_generated = self.__specific_obj.key_generated
+        self.destroy()
+
+
+class DefaultKeySetupGUI(DKSG):
+    """
+    Default Setup GUI for Salt Key, Main DB, Local DB, and Pointer files
+    """
+
+    def __init__(self, local_dir=None):
+        DKSG.__init__(self, local_dir=local_dir)
+        self.mainloop()
+
+
+class MDG(Tk):
+    __pointer = None
+
+    def __init__(self, local_db_dir, main_db_path=None, pointer=None):
         Tk.__init__(self)
 
         from .data import DataConfig
-        from . import default_pepper_filepath
 
         if not isinstance(pointer, (DataConfig, type(None))):
             raise ValueError("'pointer' %r is not an instance of DataConfig" % pointer)
@@ -22,33 +339,16 @@ class SG(Tk):
             raise ValueError("'local_db_dir' %r is not an instance of String" % local_db_dir)
         if not isinstance(main_db_path, (str, type(None))):
             raise ValueError("'main_db_path' %r is not an instance of String" % main_db_path)
-        if not isinstance(salt_key_path, (str, type(None))):
-            raise ValueError("'salt_key_path' %r is not an instance of String" % salt_key_path)
-        if not isinstance(pepper_key_path, (str, type(None))):
-            raise ValueError("'pepper_key_path' %r is not an instance of String" % pepper_key_path)
         if not os.path.isdir(local_db_dir):
             raise ValueError("'local_db_dir' %r is not a valid directory" % local_db_dir)
         if main_db_path and not os.path.exists(main_db_path):
             main_db_path = os.path.dirname(main_db_path)
-        if salt_key_path and not os.path.exists(salt_key_path):
-            salt_key_path = os.path.dirname(salt_key_path)
-
-        if not pepper_key_path and os.path.exists(default_pepper_filepath()):
-            self.__pepper_key = default_pepper_filepath()
-
-        if not pepper_key_path:
-            raise ValueError("'pepper_key_path' does not exist or wasn't populated. Please specify a pepper key filepath or create a new pepper key (KGlobal -c <dir (optional)>)")
 
         self.__pointer = pointer
         self.__local_db_dir = local_db_dir
-        self.__salt_key_path = StringVar()
         self.__main_db_path = StringVar()
-        self.__salt_key_dir = StringVar()
         self.__main_db_dir = StringVar()
 
-        if salt_key_path:
-            self.__salt_key_path.set(salt_key_path)
-
         if main_db_path:
             self.__main_db_path.set(main_db_path)
 
@@ -63,12 +363,12 @@ class SG(Tk):
         return self.__pointer
 
     def __build(self):
-        header = ['Welcome to new settings file setup!', 'Please fill out the below fields to setup']
-        header2 = ['Welcome to existing settings file setup!', 'Please fill out the below fields to setup']
+        header = ['Welcome to main database setup!', 'Please fill out the below fields to setup']
+        header2 = ['Welcome to existing main database setup!', 'Please fill out the below fields to setup']
 
         # Set GUI Geometry and GUI Title
-        self.geometry('280x215+550+150')
-        self.title('Settings Setup')
+        self.geometry('280x135+550+150')
+        self.title('Main Database Setup')
         self.resizable(False, False)
 
         # Set GUI Frames
@@ -79,22 +379,18 @@ class SG(Tk):
         t.add(existing_tab, text='Existing')
 
         new_header_frame = Frame(new_tab)
-        new_salt_frame = LabelFrame(new_tab, text='Salt Key', width=508, height=70)
         new_settings_frame = LabelFrame(new_tab, text='Main DB', width=508, height=70)
         new_buttons_frame = Frame(new_tab)
         existing_header_frame = Frame(existing_tab)
-        existing_salt_frame = LabelFrame(existing_tab, text='Salt Key', width=508, height=70)
         existing_main_frame = LabelFrame(existing_tab, text='Main DB', width=508, height=70)
         existing_buttons_frame = Frame(existing_tab)
 
         # Apply Frames into GUI
         t.pack(fill="both")
         new_header_frame.pack(fill="both")
-        new_salt_frame.pack(fill="both")
         new_settings_frame.pack(fill="both")
         new_buttons_frame.pack(fill="both")
         existing_header_frame.pack(fill="both")
-        existing_salt_frame.pack(fill="both")
         existing_main_frame.pack(fill="both")
         existing_buttons_frame.pack(fill="both")
 
@@ -104,20 +400,9 @@ class SG(Tk):
         header2 = Message(self, text='\n'.join(header2), width=500, justify=CENTER)
         header2.pack(in_=existing_header_frame)
 
-        # Apply Widgets to new_salt_frame
-        #   Apply Salt Directory Entry Box Widget
-        salt_dir_label = Label(new_salt_frame, text='Directory:')
-        salt_dir_entry = Entry(new_salt_frame, textvariable=self.__salt_key_dir)
-        salt_dir_label.grid(row=0, column=0, padx=4, pady=5)
-        salt_dir_entry.grid(row=0, column=1, padx=4, pady=5)
-
-        #   Apply Salt Directory Finder Button Widget
-        find_salt_dir_button = Button(new_salt_frame, text='...', width=8, command=self.__salt_dir_gui)
-        find_salt_dir_button.grid(row=0, column=2, padx=4, pady=5)
-
         # Apply Widgets to new_settings_frame
         #    Apply Settings Directory Entry Box Widget
-        settings_dir_label = Label(new_settings_frame, text='Directory:')
+        settings_dir_label = Label(new_settings_frame, text='DB Dir:')
         settings_dir_entry = Entry(new_settings_frame, textvariable=self.__main_db_dir)
         settings_dir_label.grid(row=0, column=0, padx=4, pady=5)
         settings_dir_entry.grid(row=0, column=1, padx=4, pady=5)
@@ -136,18 +421,8 @@ class SG(Tk):
         cancel_button.pack(in_=new_buttons_frame, side=RIGHT, padx=7, pady=7)
 
         # Apply Widgets to existing_frame
-        #   Apply Salt Directory Entry Box Widget
-        salt_fp_label = Label(existing_salt_frame, text='Filepath:')
-        salt_fp_entry = Entry(existing_salt_frame, textvariable=self.__salt_key_path)
-        salt_fp_label.grid(row=0, column=0, padx=4, pady=5)
-        salt_fp_entry.grid(row=0, column=1, padx=4, pady=5)
-
-        #   Apply Salt File Name Finder Button Widget
-        find_salt_name_button = Button(existing_salt_frame, text='...', width=8, command=self.__salt_file_gui)
-        find_salt_name_button.grid(row=0, column=2, padx=4, pady=5)
-
         #   Apply Main Filepath Entry Box Widget
-        settings_fp_label = Label(existing_main_frame, text='Filepath:')
+        settings_fp_label = Label(existing_main_frame, text='DB Fp:')
         settings_fp_entry = Entry(existing_main_frame, textvariable=self.__main_db_path)
         settings_fp_label.grid(row=1, column=0, padx=4, pady=5)
         settings_fp_entry.grid(row=1, column=1, padx=4, pady=5)
@@ -156,13 +431,9 @@ class SG(Tk):
         find_settings_name_button = Button(existing_main_frame, text='...', width=3, command=self.__main_file_gui)
         find_settings_name_button.grid(row=1, column=2, padx=4, pady=5)
 
-        #   Apply Main File Directory Finder Button Widget
-        find_settings_name_button = Button(existing_main_frame, text='Dir', width=3, command=self.__main_dir_gui2)
-        find_settings_name_button.grid(row=1, column=3, padx=4, pady=5)
-
         # Apply Buttons to the existing_buttons_frame
         #     Generate button
-        generate_button = Button(self, text='Generate', width=15, command=self.__generate2)
+        generate_button = Button(self, text='Link DB', width=15, command=self.__generate2)
         generate_button.pack(in_=existing_buttons_frame, side=LEFT, padx=7, pady=7)
 
         #     Cancel button
@@ -173,32 +444,6 @@ class SG(Tk):
         self.__pointer = None
         self.destroy()
 
-    def __salt_dir_gui(self):
-        if self.__salt_key_dir.get() and os.path.exists(self.__salt_key_dir.get()):
-            init_dir = self.__salt_key_dir.get()
-        else:
-            init_dir = self.__local_db_dir
-
-        salt_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Salt Directory', parent=self)
-
-        if salt_dir:
-            self.__salt_key_dir.set(salt_dir)
-
-    def __salt_file_gui(self):
-        if self.__salt_key_path.get() and os.path.exists(self.__salt_key_path.get()):
-            init_dir = os.path.dirname(self.__salt_key_path.get())
-            init_file = os.path.basename(self.__salt_key_path.get())
-        else:
-            init_dir = self.__local_db_dir
-            init_file = ''
-
-        file_path = filedialog.askopenfile(initialdir=init_dir, initialfile=init_file, title='Select Salt Key',
-                                           filetypes=[("key files", "*.key")], parent=self)
-
-        if file_path:
-            self.__salt_key_path.set(file_path.name)
-            file_path.close()
-
     def __main_dir_gui(self):
         if self.__main_db_dir.get() and os.path.exists(self.__main_db_dir.get()):
             init_dir = self.__main_db_dir.get()
@@ -210,17 +455,6 @@ class SG(Tk):
         if settings_dir:
             self.__main_db_dir.set(settings_dir)
 
-    def __main_dir_gui2(self):
-        if self.__main_db_path.get() and os.path.exists(self.__main_db_path.get()):
-            init_dir = self.__main_db_path.get()
-        else:
-            init_dir = self.__local_db_dir
-
-        settings_dir = filedialog.askdirectory(initialdir=init_dir, title='Select Main DB Directory', parent=self)
-
-        if settings_dir:
-            self.__main_db_path.set(settings_dir)
-
     def __main_file_gui(self):
         if self.__main_db_path.get() and os.path.exists(self.__main_db_path.get()):
             init_dir = os.path.dirname(self.__main_db_path.get())
@@ -238,30 +472,22 @@ class SG(Tk):
             settings_name.close()
 
     def __generate2(self):
-        if not self.__salt_key_path:
-            showerror('Field Empty Error!', 'No value has been inputed for Salt Key Path', parent=self)
-        elif not self.__main_db_path:
+        if not self.__main_db_path:
             showerror('Field Empty Error!', 'No value has been inputed for Main DB Path', parent=self)
-        elif not os.path.isfile(self.__salt_key_path.get()):
-            showerror('Invalid Path Error!', 'Salt Key Path is not a file!', parent=self)
         elif not os.path.isfile(self.__main_db_path.get()) and not os.path.isdir(self.__main_db_path.get()):
             showerror('Invalid Path Error!', 'Main DB Path is not a file or directory!', parent=self)
-        elif not os.path.exists(self.__salt_key_path.get()):
-            showerror('Path Exist Error!', 'Salt Key Path does not exist!', parent=self)
         elif not os.path.exists(self.__main_db_path.get()):
             showerror('Path Exist Error!', 'Main DB Path does not exist!', parent=self)
-
         else:
             if not self.__pointer:
                 from .data import DataConfig
 
-                self.__pointer = DataConfig(file_dir=self.__local_db_dir,
-                                            file_name_prefix='Script_Pointer', file_ext='ptr',
-                                            pepper_key_fp=self.__pepper_key, new_salt_key=False, encrypt=True)
+                self.__pointer = DataConfig(file_dir=self.__local_db_dir, file_name_prefix='Script_Pointer',
+                                            file_ext='ptr', encrypt=True)
 
-            self.__pointer.setcrypt(key='Key_Path', val=self.__salt_key_path.get(), private=True)
             self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_dir, 'Local_Settings.db'),
                                     private=True)
+
             if os.path.isfile(self.__main_db_path.get()):
                 self.__pointer.setcrypt(key='Main_DB_Path', val=self.__main_db_path.get(), private=True)
             else:
@@ -271,33 +497,19 @@ class SG(Tk):
             self.destroy()
 
     def __generate(self):
-        if not self.__salt_key_dir:
-            showerror('Field Empty Error!', 'No value has been inputed for Salt Key Directory', parent=self)
-        elif not self.__main_db_dir:
+        if not self.__main_db_dir:
             showerror('Field Empty Error!', 'No value has been inputed for Main DB Directory', parent=self)
-        elif not os.path.isdir(self.__salt_key_dir.get()):
-            showerror('Invalid Directory!', 'Salt Key Directory is an invalid directory', parent=self)
         elif not os.path.isdir(self.__main_db_dir.get()):
             showerror('Invalid Directory!', 'Main DB Directory is an invalid directory', parent=self)
-        elif not os.path.exists(self.__salt_key_dir.get()):
-            showerror('Directory Not Exist!', 'Salt Key Directory does not exist', parent=self)
         elif not os.path.exists(self.__main_db_dir.get()):
             showerror('Directory Not Exist!', 'Main DB Directory does not exist', parent=self)
         else:
             if not self.__pointer:
                 from .data import DataConfig
 
-                self.__pointer = DataConfig(file_dir=self.__local_db_dir,
-                                            file_name_prefix='Script_Pointer', file_ext='ptr',
-                                            pepper_key_fp=self.__pepper_key, new_salt_key=False, encrypt=True)
+                self.__pointer = DataConfig(file_dir=self.__local_db_dir, file_name_prefix='Script_Pointer',
+                                            file_ext='ptr', encrypt=True)
 
-            salt_path = os.path.join(self.__salt_key_dir.get(), 'Salt_Key.key')
-
-            if not os.path.exists(salt_path):
-                from .data import create_key
-                create_key(self.__salt_key_dir.get(), 'Salt_Key.key')
-
-            self.__pointer.setcrypt(key='Key_Path', val=salt_path, private=True)
             self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_dir, 'Local_Settings.db'),
                                     private=True)
             self.__pointer.setcrypt(key='Main_DB_Path', val=os.path.join(self.__main_db_dir.get(), 'Main_Settings.db'),
@@ -306,12 +518,12 @@ class SG(Tk):
             self.destroy()
 
 
-class SetupGUI(SG):
+class MainDatabaseGUI(MDG):
     """
     Setup GUI for Salt Key, Main DB, Local DB, and Pointer files
     """
 
-    def __init__(self, local_db_dir, main_db_path=None, pepper_key_path=None, salt_key_path=None, pointer=None):
+    def __init__(self, local_db_dir, main_db_path=None, pointer=None):
         """
         :param local_db_dir:  Local DB directory (aka local script directory)
         :param main_db_path: (Optional) Main DB filepath
@@ -320,8 +532,7 @@ class SetupGUI(SG):
         :param pointer: (Optional) Pointer .ptr DataConfig instance class
         """
 
-        SG.__init__(self, local_db_dir=local_db_dir, main_db_path=main_db_path, pepper_key_path=pepper_key_path,
-                    salt_key_path=salt_key_path, pointer=pointer)
+        MDG.__init__(self, local_db_dir=local_db_dir, main_db_path=main_db_path, pointer=pointer)
         self.mainloop()
 
 
@@ -589,22 +800,22 @@ class SSG(Tk):
     def __init__(self, server=None, database=None):
         Tk.__init__(self)
         from .data import CryptHandle
-        
+
         if not isinstance(server, (str, type(None))):
             raise ValueError("'server' %r is not a String" % server)
         if not isinstance(database, (str, type(None))):
             raise ValueError("'database' %r is not a String" % database)
-        
+
         self.__server = StringVar()
         self.__database = StringVar()
         self.__server_obj = CryptHandle()
         self.__database_obj = CryptHandle()
-        
+
         if server:
             self.__server.set(server)
         if database:
             self.__database.set(database)
-        
+
         self.__build()
 
     @property
@@ -622,7 +833,7 @@ class SSG(Tk):
         """
 
         return self.__database_obj
-        
+
     def __build(self):
         header = ['Welcome to SQL Server Settings!', 'Please fill out the fields below:']
 
@@ -666,7 +877,7 @@ class SSG(Tk):
         #     Cancel button
         cancel_button = Button(self, text='Cancel', width=13, command=self.destroy)
         cancel_button.pack(in_=buttons_frame, side=RIGHT, padx=7, pady=7)
-        
+
     def __save(self):
         if not self.__server:
             showerror('Field Empty Error!', 'No value has been inputed for Server', parent=self)
