@@ -335,14 +335,18 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         else:
             return self.__cursor_results
 
-    def close_connections(self, destroy_self=False):
+    def close_connections(self, destroy_self=False, enable_log=True):
         """
         Closes all cursors and engines
 
         :param destroy_self: (True/False) Request self destruction of class
+        :param enable_log: (True/False) Enables logging
         """
-        log.debug('SQL Connection (%s): Releasing SQL engine %s', str(self.__sql_config), self.engine_id)
-        self.__release_coms()
+
+        if enable_log:
+            log.debug('SQL Connection (%s): Releasing SQL engine %s', str(self.__sql_config), self.engine_id)
+
+        self.__release_coms(enable_log=enable_log)
 
         if destroy_self and self.__engine_sql_class:
             self.__engine_sql_class.remove_engine_from_pool(self)
@@ -365,12 +369,12 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         if len(self.__cursors.queue) > 0:
             self.__cursors.queue.remove(cursor)
 
-    def __release_coms(self):
+    def __release_coms(self, enable_log=True):
         if self.__cursors.qsize() > 0:
             with self.__engine_lock:
                 while True:
                     try:
-                        self.__cursors.get(block=False).close()
+                        self.__cursors.get(block=False).close(write_log=enable_log)
                     except Empty:
                         break
 
