@@ -18,7 +18,7 @@ class TBoxBase(object):
     __main_config = None
     __pointer = None
 
-    def __init__(self, script_path, pepper_key_fp=None):
+    def __init__(self, script_path):
         """
         Lets setup SQLQueue, Logging, Main Config, and Local Config
 
@@ -28,14 +28,23 @@ class TBoxBase(object):
         :param max_pool_size: (Optional) SQL max poolsize for connection queue
         """
 
-        from . import default_pepper_filepath
+        from . import default_key_dir
+        from .setup_gui import DefaultKeySetupGUI
         from .data import DataConfig
 
+        self.__base_dir = os.path.dirname(script_path)
+        key_ptr_fp = os.path.join(default_key_dir(), "Key.dir")
+        salt_key_fp = os.path.join(default_key_dir(), "Salt.key")
+        pepper_key_fp = os.path.join(default_key_dir(), "Pepper.key")
+
+        if not (os.path.exists(salt_key_fp) and os.path.exists(pepper_key_fp)) or not os.path.exists(key_ptr_fp):
+            obj = DefaultKeySetupGUI(self.__base_dir)
+
+            if not obj.key_generated:
+                raise ValueError("Unable to establish toolbox because key creation wasn't established")
+
         if not isinstance(script_path, str):
             raise ValueError("'script_path' %r is not a String" % script_path)
-
-        self.__base_dir = os.path.dirname(script_path)
-
         if not os.path.exists(self.__base_dir):
             raise ValueError("'script_path' %r does not exist as directory" % self.__base_dir)
         if not os.path.basename(script_path):
@@ -48,11 +57,6 @@ class TBoxBase(object):
         else:
             self.__base_name = os.path.splitext(os.path.basename(script_path))[0]
 
-        if pepper_key_fp:
-            self.__pepper_key_fp = pepper_key_fp
-        else:
-            self.__pepper_key_fp = default_pepper_filepath()
-
         if not self.__base_name:
             raise ValueError("'script_path' %r doesn't have a proper file name" % os.path.basename(script_path))
 
@@ -60,7 +64,7 @@ class TBoxBase(object):
 
         if os.path.exists(script_path):
             self.pointer = DataConfig(file_dir=self.__base_dir, file_name_prefix=self.__base_name, file_ext='ptr',
-                                      pepper_key_fp=self.__pepper_key_fp, new_salt_key=False, encrypt=True)
+                                      encrypt=True)
         else:
             self.__new_pointer()
 
@@ -95,16 +99,8 @@ class TBoxBase(object):
             raise ValueError("'pointer' %r is not an instance of DataConfig" % pointer)
 
         if pointer:
-            old_key_path = None
             old_mdb_path = None
 
-            if 'Key_Path' in pointer.keys():
-                if not isinstance(pointer['Key_Path'], CryptHandle):
-                    del pointer['Key_Path']
-                elif not os.path.exists(pointer['Key_Path'].decrypt()):
-                    old_key_path = pointer['Key_Path'].decrypt()
-                    del pointer['Key_Path']
-
             if 'Main_DB_Path' in pointer.keys() and not isinstance(pointer['Main_DB_Path'], CryptHandle):
                 old_mdb_path = pointer['Main_DB_Path']
                 del pointer['Main_DB_Path']
@@ -112,23 +108,22 @@ class TBoxBase(object):
             if 'Local_DB_Path' in pointer.keys() and not isinstance(pointer['Local_DB_Path'], CryptHandle):
                 del pointer['Local_DB_Path']
 
-                if 'Key_Path' in pointer.keys() and 'Main_DB_Path' in pointer.keys():
-                    lpath = os.path.join(self.__base_dir, '%s.db' % self.__base_name)
-                    pointer['Local_DB_Path'].setcrypt(key=pointer['Key_Path'], val=lpath)
+                if 'Main_DB_Path' in pointer.keys():
+                    lpath = os.path.join(self.__base_dir, 'Local_Settings.db')
+                    pointer['Local_DB_Path'].setcrypt(key='Local_DB_Path', val=lpath)
 
-            if 'Key_Path' in pointer.keys() and 'Main_DB_Path' in pointer.keys() and 'Local_DB_Path' in pointer.keys():
+            if 'Main_DB_Path' in pointer.keys() and 'Local_DB_Path' in pointer.keys():
                 self.__pointer = pointer
                 self.__set_config()
             else:
-                self.__new_pointer(pointer, old_key_path, old_mdb_path)
+                self.__new_pointer(pointer, old_mdb_path)
         else:
             self.__pointer = pointer
 
-    def __new_pointer(self, pointer=None, old_key_path=None, old_db_path=None):
+    def __new_pointer(self, pointer=None, old_db_path=None):
         from .setup_gui import SetupGUI
 
-        obj = SetupGUI(local_db_dir=self.__base_dir, pointer=pointer, pepper_key_path=self.__pepper_key_fp,
-                       salt_key_path=old_key_path, main_db_path=old_db_path)
+        obj = SetupGUI(local_db_dir=self.__base_dir, pointer=pointer, main_db_path=old_db_path)
 
         if obj.pointer:
             self.pointer = obj.pointer
@@ -137,7 +132,6 @@ class TBoxBase(object):
         if self.__pointer:
             from .data import DataConfig
 
-            key = self.__pointer['Key_Path']
             main_db = self.__pointer['Main_DB_Path']
             local_db = self.__pointer['Local_DB_Path']
 
@@ -145,19 +139,14 @@ class TBoxBase(object):
             main_file_name_prefix = os.path.splitext(os.path.basename(main_db.decrypt()))
             self.__local_config = DataConfig(file_dir=os.path.dirname(local_db.decrypt()),
                                              file_name_prefix=local_file_name_prefix[0],
-                                             file_ext=local_file_name_prefix[1].replace('.', ''),
-                                             salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
+                                             file_ext=local_file_name_prefix[1].replace('.', ''), encrypt=True)
             self.__main_config = DataConfig(file_dir=os.path.dirname(main_db.decrypt()),
                                             file_name_prefix=main_file_name_prefix[0],
-                                            file_ext=main_file_name_prefix[1].replace('.', ''),
-                                            salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
+                                            file_ext=main_file_name_prefix[1].replace('.', ''), encrypt=True)
 
-    def __del__(self):
-        SQLQueue.__del__(self)
-        LogHandle.__del__(self)
 
-class Toolbox(TBoxBase, LogHandle, SQLQueue):
-    def __init__(self, script_path, pepper_key_fp=None, logging_dir=None, logging_base_name=None, max_pool_size=None,
+class Toolbox(TBoxBase, SQLQueue, LogHandle):
+    def __init__(self, script_path, logging_dir=None, logging_base_name=None, max_pool_size=None,
                  *args, **kwargs):
         if logging_dir and os.path.exists(logging_dir) and os.path.isdir(logging_dir):
             file_dir = logging_dir
@@ -170,7 +159,7 @@ class Toolbox(TBoxBase, LogHandle, SQLQueue):
             file_dir = None
             base_name = None
 
-        TBoxBase.__init__(self, script_path=script_path, pepper_key_fp=pepper_key_fp)
+        TBoxBase.__init__(self, script_path=script_path)
         SQLQueue.__init__(self, max_pool_size=max_pool_size)
         LogHandle.__init__(self, file_dir=file_dir, base_name=base_name)
 
@@ -347,4 +336,8 @@ class Toolbox(TBoxBase, LogHandle, SQLQueue):
 
         for engine in self.pool_list:
             if isinstance(engine, SQLEngineClass) and engine.sql_config == config:
-                return engine
\ No newline at end of file
+                return engine
+
+    def __del__(self):
+        SQLQueue.__del__(self)
+        LogHandle.__del__(self)
